@@ -2,7 +2,7 @@
  * \file Ellipsoid.hpp
  * \brief Header for GeographicLib::Ellipsoid class
  *
- * Copyright (c) Charles Karney (2012-2020) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2012-2022) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -58,7 +58,7 @@ namespace GeographicLib {
     ///@{
 
     /**
-     * Constructor for a ellipsoid with
+     * Constructor for an ellipsoid with
      *
      * @param[in] a equatorial radius (meters).
      * @param[in] f flattening of ellipsoid.  Setting \e f = 0 gives a sphere.
@@ -82,7 +82,7 @@ namespace GeographicLib {
     /**
      * @return \e b the polar semi-axis (meters).
      **********************************************************************/
-    Math::real MinorRadius() const { return _b; }
+    Math::real PolarRadius() const { return _b; }
 
     /**
      * @return \e L the distance between the equator and a pole along a
@@ -105,12 +105,6 @@ namespace GeographicLib {
      **********************************************************************/
     Math::real Volume() const
     { return (4 * Math::pi()) * Math::sq(_a) * _b / 3; }
-
-    /**
-     * \deprecated An old name for EquatorialRadius().
-     **********************************************************************/
-    GEOGRAPHICLIB_DEPRECATED("Use EquatorialRadius()")
-    Math::real MajorRadius() const { return EquatorialRadius(); }
     ///@}
 
     /** \name %Ellipsoid shape
