@@ -2,7 +2,7 @@
  * \file GeoCoords.hpp
  * \brief Header for GeographicLib::GeoCoords class
  *
- * Copyright (c) Charles Karney (2008-2020) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2008-2022) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -240,9 +240,7 @@ namespace GeographicLib {
                       _zone, _northp, _easting, _northing, _gamma, _k,
                       zone);
       _lat = latitude;
-      _long = longitude;
-      if (_long >= 180) _long -= 360;
-      else if (_long < -180) _long += 360;
+      _long = Math::AngNormalize(longitude);
       CopyToAlt();
     }
 
@@ -538,12 +536,6 @@ namespace GeographicLib {
      * based on this ellipsoid.)
      **********************************************************************/
     Math::real Flattening() const { return UTMUPS::Flattening(); }
-
-    /**
-     * \deprecated An old name for EquatorialRadius().
-     **********************************************************************/
-    GEOGRAPHICLIB_DEPRECATED("Use EquatorialRadius()")
-    Math::real MajorRadius() const { return EquatorialRadius(); }
     ///@}
 
   };
