@@ -2,7 +2,7 @@
  * \file Geodesic.hpp
  * \brief Header for GeographicLib::Geodesic class
  *
- * Copyright (c) Charles Karney (2009-2020) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2009-2022) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -30,12 +30,12 @@ namespace GeographicLib {
   /**
    * \brief %Geodesic calculations
    *
-   * The shortest path between two points on a ellipsoid at (\e lat1, \e lon1)
+   * The shortest path between two points on an ellipsoid at (\e lat1, \e lon1)
    * and (\e lat2, \e lon2) is called the geodesic.  Its length is \e s12 and
    * the geodesic from point 1 to point 2 has azimuths \e azi1 and \e azi2 at
    * the two end points.  (The azimuth is the heading measured clockwise from
    * north.  \e azi2 is the "forward" azimuth, i.e., the heading that takes you
-   * beyond point 2 not back to point 1.)  In the figure below, latitude if
+   * beyond point 2 not back to point 1.)  In the figure below, latitude is
    * labeled &phi;, longitude &lambda; (with &lambda;<sub>12</sub> =
    * &lambda;<sub>2</sub> &minus; &lambda;<sub>1</sub>), and azimuth &alpha;.
    *
@@ -209,7 +209,7 @@ namespace GeographicLib {
     static real Astroid(real x, real y);
 
     real _a, _f, _f1, _e2, _ep2, _n, _b, _c2, _etol2;
-    real _A3x[nA3x_], _C3x[nC3x_], _C4x[nC4x_];
+    real _aA3x[nA3x_], _cC3x[nC3x_], _cC4x[nC4x_];
 
     void Lengths(real eps, real sig12,
                  real ssig1, real csig1, real dn1,
@@ -254,7 +254,7 @@ namespace GeographicLib {
 
     /**
      * Bit masks for what calculations to do.  These masks do double duty.
-     * They signify to the GeodesicLine::GeodesicLine constructor and to
+     * They signify to the GeodesicLine constructor and to
      * Geodesic::Line what capabilities should be included in the GeodesicLine
      * object.  They also specify which results to return in the general
      * routines Geodesic::GenDirect and Geodesic::GenInverse routines.
@@ -289,6 +289,12 @@ namespace GeographicLib {
        * @hideinitializer
        **********************************************************************/
       DISTANCE      = 1U<<10 | CAP_C1,
+      /**
+       * A combination of the common capabilities: Geodesic::LATITUDE,
+       * Geodesic::LONGITUDE, Geodesic::AZIMUTH, Geodesic::DISTANCE.
+       * @hideinitializer
+       **********************************************************************/
+      STANDARD      = LATITUDE | LONGITUDE | AZIMUTH | DISTANCE,
       /**
        * Allow distance \e s12 to be used as input in the direct geodesic
        * problem.
@@ -316,7 +322,7 @@ namespace GeographicLib {
        **********************************************************************/
       LONG_UNROLL   = 1U<<15,
       /**
-       * All capabilities, calculate everything.  (LONG_UNROLL is not
+       * All capabilities, calculate everything.  (Geodesic::LONG_UNROLL is not
        * included in this mask.)
        * @hideinitializer
        **********************************************************************/
@@ -327,7 +333,7 @@ namespace GeographicLib {
      **********************************************************************/
     ///@{
     /**
-     * Constructor for a ellipsoid with
+     * Constructor for an ellipsoid with
      *
      * @param[in] a equatorial radius (meters).
      * @param[in] f flattening of ellipsoid.  Setting \e f = 0 gives a sphere.
@@ -956,12 +962,6 @@ namespace GeographicLib {
      **********************************************************************/
     Math::real EllipsoidArea() const
     { return 4 * Math::pi() * _c2; }
-
-    /**
-     * \deprecated An old name for EquatorialRadius().
-     **********************************************************************/
-    GEOGRAPHICLIB_DEPRECATED("Use EquatorialRadius()")
-    Math::real MajorRadius() const { return EquatorialRadius(); }
     ///@}
 
     /**
