@@ -2,7 +2,7 @@
  * \file MagneticModel.hpp
  * \brief Header for GeographicLib::MagneticModel class
  *
- * Copyright (c) Charles Karney (2011-2021) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2011-2022) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -78,11 +78,11 @@ namespace GeographicLib {
     static const int idlength_ = 8;
     std::string _name, _dir, _description, _date, _filename, _id;
     real _t0, _dt0, _tmin, _tmax, _a, _hmin, _hmax;
-    int _Nmodels, _Nconstants, _nmx, _mmx;
+    int _nNmodels, _nNconstants, _nmx, _mmx;
     SphericalHarmonic::normalization _norm;
     Geocentric _earth;
-    std::vector< std::vector<real> > _G;
-    std::vector< std::vector<real> > _H;
+    std::vector< std::vector<real> > _gG;
+    std::vector< std::vector<real> > _hH;
     std::vector<SphericalHarmonic> _harm;
     void Field(real t, real lat, real lon, real h, bool diffp,
                real& Bx, real& By, real& Bz,
@@ -144,7 +144,7 @@ namespace GeographicLib {
     /**
      * Evaluate the components of the geomagnetic field.
      *
-     * @param[in] t the time (years).
+     * @param[in] t the time (fractional years).
      * @param[in] lat latitude of the point (degrees).
      * @param[in] lon longitude of the point (degrees).
      * @param[in] h the height of the point above the ellipsoid (meters).
@@ -153,6 +153,9 @@ namespace GeographicLib {
      *   (nanotesla).
      * @param[out] Bz the vertical (up) component of the magnetic field
      *   (nanotesla).
+     *
+     * Use Utility::fractionalyear to convert a date of the form yyyy-mm or
+     * yyyy-mm-dd into a fractional year.
      **********************************************************************/
     void operator()(real t, real lat, real lon, real h,
                     real& Bx, real& By, real& Bz) const {
@@ -164,7 +167,7 @@ namespace GeographicLib {
      * Evaluate the components of the geomagnetic field and their time
      * derivatives
      *
-     * @param[in] t the time (years).
+     * @param[in] t the time (fractional years).
      * @param[in] lat latitude of the point (degrees).
      * @param[in] lon longitude of the point (degrees).
      * @param[in] h the height of the point above the ellipsoid (meters).
@@ -176,6 +179,9 @@ namespace GeographicLib {
      * @param[out] Bxt the rate of change of \e Bx (nT/yr).
      * @param[out] Byt the rate of change of \e By (nT/yr).
      * @param[out] Bzt the rate of change of \e Bz (nT/yr).
+     *
+     * Use Utility::fractionalyear to convert a date of the form yyyy-mm or
+     * yyyy-mm-dd into a fractional year.
      **********************************************************************/
     void operator()(real t, real lat, real lon, real h,
                     real& Bx, real& By, real& Bz,
@@ -188,7 +194,7 @@ namespace GeographicLib {
      * points with constant \e lat, \e h, and \e t and varying \e lon to be
      * computed efficiently.
      *
-     * @param[in] t the time (years).
+     * @param[in] t the time (fractional years).
      * @param[in] lat latitude of the point (degrees).
      * @param[in] h the height of the point above the ellipsoid (meters).
      * @exception std::bad_alloc if the memory necessary for creating a
@@ -200,13 +206,16 @@ namespace GeographicLib {
      * If the field at several points on a circle of latitude need to be
      * calculated then creating a MagneticCircle and using its member functions
      * will be substantially faster, especially for high-degree models.
+     *
+     * Use Utility::fractionalyear to convert a date of the form yyyy-mm or
+     * yyyy-mm-dd into a fractional year.
      **********************************************************************/
     MagneticCircle Circle(real t, real lat, real h) const;
 
     /**
      * Compute the magnetic field in geocentric coordinate.
      *
-     * @param[in] t the time (years).
+     * @param[in] t the time (fractional years).
      * @param[in] X geocentric coordinate (meters).
      * @param[in] Y geocentric coordinate (meters).
      * @param[in] Z geocentric coordinate (meters).
@@ -216,6 +225,9 @@ namespace GeographicLib {
      * @param[out] BXt the rate of change of \e BX (nT/yr).
      * @param[out] BYt the rate of change of \e BY (nT/yr).
      * @param[out] BZt the rate of change of \e BZ (nT/yr).
+     *
+     * Use Utility::fractionalyear to convert a date of the form yyyy-mm or
+     * yyyy-mm-dd into a fractional year.
      **********************************************************************/
     void FieldGeocentric(real t, real X, real Y, real Z,
                          real& BX, real& BY, real& BZ,
@@ -365,12 +377,6 @@ namespace GeographicLib {
      * @return \e Mmax the maximum order of the components of the model.
      **********************************************************************/
     int Order() const { return _mmx; }
-
-    /**
-     * \deprecated An old name for EquatorialRadius().
-     **********************************************************************/
-    GEOGRAPHICLIB_DEPRECATED("Use EquatorialRadius()")
-    Math::real MajorRadius() const { return EquatorialRadius(); }
     ///@}
 
     /**
