@@ -2,13 +2,18 @@
  * \file CassiniSoldner.cpp
  * \brief Implementation for GeographicLib::CassiniSoldner class
  *
- * Copyright (c) Charles Karney (2009-2015) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2009-2022) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
 
 #include <GeographicLib/CassiniSoldner.hpp>
 
+#if defined(_MSC_VER)
+// Squelch warnings about enum-float expressions
+#  pragma warning (disable: 5055)
+#endif
+
 namespace GeographicLib {
 
   using namespace std;
@@ -37,20 +42,20 @@ namespace GeographicLib {
       return;
     real dlon = Math::AngDiff(LongitudeOrigin(), lon);
     real sig12, s12, azi1, azi2;
-    sig12 = _earth.Inverse(lat, -abs(dlon), lat, abs(dlon), s12, azi1, azi2);
+    sig12 = _earth.Inverse(lat, -fabs(dlon), lat, fabs(dlon), s12, azi1, azi2);
     sig12 *= real(0.5);
     s12 *= real(0.5);
     if (s12 == 0) {
       real da = Math::AngDiff(azi1, azi2)/2;
-      if (abs(dlon) <= 90) {
-        azi1 = 90 - da;
-        azi2 = 90 + da;
+      if (fabs(dlon) <= Math::qd) {
+        azi1 = Math::qd - da;
+        azi2 = Math::qd + da;
       } else {
-        azi1 = -90 - da;
-        azi2 = -90 + da;
+        azi1 = -Math::qd - da;
+        azi2 = -Math::qd + da;
       }
     }
-    if (dlon < 0) {
+    if (signbit(dlon)) {
       azi2 = azi1;
       s12 = -s12;
       sig12 = -sig12;
@@ -67,7 +72,7 @@ namespace GeographicLib {
     Math::sincosd(perp.EquatorialAzimuth(), salp0, calp0);
     real
       sbet1 = lat >=0 ? calp0 : -calp0,
-      cbet1 = abs(dlon) <= 90 ? abs(salp0) : -abs(salp0),
+      cbet1 = fabs(dlon) <= Math::qd ? fabs(salp0) : -fabs(salp0),
       sbet01 = sbet1 * _cbet0 - cbet1 * _sbet0,
       cbet01 = cbet1 * _cbet0 + sbet1 * _sbet0,
       sig01 = atan2(sbet01, cbet01) / Math::degree();
@@ -83,7 +88,7 @@ namespace GeographicLib {
     real lat1, lon1;
     real azi0, t;
     _meridian.Position(y, lat1, lon1, azi0);
-    _earth.Direct(lat1, lon1, azi0 + 90, x, lat, lon, azi, rk, t);
+    _earth.Direct(lat1, lon1, azi0 + Math::qd, x, lat, lon, azi, rk, t);
   }
 
 } // namespace GeographicLib
